nvector.objects.GeoPath
=======================

.. currentmodule:: nvector.objects

.. autoclass:: GeoPath

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GeoPath.__init__
      ~GeoPath.closest_point_on_great_circle
      ~GeoPath.closest_point_on_path
      ~GeoPath.cross_track_distance
      ~GeoPath.ecef_vectors
      ~GeoPath.geo_points
      ~GeoPath.interpolate
      ~GeoPath.intersect
      ~GeoPath.intersection
      ~GeoPath.nvector_normals
      ~GeoPath.nvectors
      ~GeoPath.on_great_circle
      ~GeoPath.on_path
      ~GeoPath.track_distance
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GeoPath.positionA
      ~GeoPath.positionB
   
   